==> snobol4-2.0.txz: usr/local/lib/snobol4/2.0/include/config.h <==
/*
 * generated Sun Jun 26 07:19:56 UTC 2016
 * on ftpmirror.your.org (FreeBSD)
 * by $Id: configure,v 1.278 2015/01/02 04:54:27 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --snolibdir=/usr/local/lib/snobol4"
#define CONFIG_HOST "ftpmirror.your.org"
#define CONFIG_DATE "Sun Jun 26 07:19:56 UTC 2016"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define OBJECT_EXT ".o"
#define SETUP_SYS "posix"
#define SHARED_OBJ_SUBDIR "shared"
#define PML_SERV
#define HAVE_BUILD_VARS
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define SIZEOF_INT_T	8	/* for use in ifdefs */
#define SIZEOF_REAL_T	8	/* for use in ifdefs */
#define HAVE_STDLIB_H
#define HAVE_UNISTD_H
#define GETRUSAGE_BUG
#define HAVE_ISFINITE
#define HAVE_STRINGS_H
#define HAVE_STRING_H
#define BINDRESVPORT_IN_RPC_H
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define HAVE_FORKPTY
#define HAVE_LIBUTIL_H
#define HAVE_PATHS_H
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/2.0/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/2.0/include"
/* NOTE: SNOLIB_FILE in config.m4 too! */
#define SNOLIB_FILE "snolib.so"
#define HAVE_FSEEKO
#define HAVE_GETTIMEOFDAY
#define HAVE_TM_GMTOFF
#define HAVE_SLEEP
#define HAVE_STRPTIME
#define HAVE_TIMEGM
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fPIC"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared -fPIC"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS ""
#define DL_LD ""
#define DL_LDFLAGS ""
#define HAVE_NDBM_H
#define COMPILER_READLINE
#define HAVE_LSTAT
/* from CFLAGS: */
#define BLOCKS

/* if the file local-defines existed it would have been incorporated here */

==> snobol4-2.1.6_1.txz: usr/local/lib/snobol4/2.1.6/include/config.h <==
/*
 * generated Tue Apr 13 10:14:37 UTC 2021
 * on loki.dragonflybsd.org (DragonFly)
 * by $Id: configure,v 1.300 2020/08/09 18:44:55 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --snolibdir=/usr/local/lib/snobol4 --mandir=/usr/local/man"
#define CONFIG_HOST "loki.dragonflybsd.org"
#define CONFIG_DATE "Tue Apr 13 10:14:37 UTC 2021"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define OBJECT_EXT ".o"
#define SETUP_SYS "posix"
#define SHARED_OBJ_SUBDIR "shared"
#define PML_SERV
#define HAVE_BUILD_VARS
#define CC_IS "gcc"
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define SIZEOF_INT_T	8	/* for use in ifdefs */
#define SIZEOF_REAL_T	8	/* for use in ifdefs */
#define HAVE_STDLIB_H
#define HAVE_UNISTD_H
#define HAVE_STDINT_H
#define HAVE_ISFINITE
#define HAVE_STRINGS_H
#define HAVE_STRING_H
#define BINDRESVPORT_IN_RPC_H
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define HAVE_FORKPTY
#define HAVE_LIBUTIL_H
#define HAVE_PATHS_H
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/2.1.6/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/2.1.6/include"
/* NOTE: SNOLIB_FILE in config.m4 too! */
#define SNOLIB_FILE "snolib.so"
#define HAVE_FSEEKO
#define HAVE_GETTIMEOFDAY
#define HAVE_TM_GMTOFF
#define HAVE_SLEEP
#define HAVE_STRPTIME
#define HAVE_TIMEGM
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fPIC"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared -fPIC"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS ""
#define DL_LD ""
#define DL_LDFLAGS ""
#define HAVE_NDBM_H
#define HAVE_LSTAT
/* from CFLAGS: */
/* from CPPFLAGS: */
#define BLOCKS

/* if the file local-defines existed it would have been incorporated here */
